# lucidoc

[![Build Status](https://travis-ci.org/vreuter/lucidoc.svg?branch=master)](https://travis-ci.org/vreuter/lucidoc)
[![Coverage Status](https://coveralls.io/repos/github/vreuter/lucidoc/badge.svg?branch=master)](https://coveralls.io/github/vreuter/lucidoc?branch=master)

From docstrings generate package API documentation in Markdown

